@@ -10,7 +10,7 @@ greple -Mcolors
 
 package App::Greple::colors;
 
-use strict;
+use v5.14;
 use warnings;
 
 use Exporter qw(import);
